Class: Google::Apis::DialogflowV2::GoogleCloudDialogflowV2DtmfParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v2/classes.rb,
lib/google/apis/dialogflow_v2/representations.rb,
lib/google/apis/dialogflow_v2/representations.rb

Overview

The message in the response that indicates the parameters of DTMF.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2DtmfParameters

Returns a new instance of GoogleCloudDialogflowV2DtmfParameters.



10753
10754
10755
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 10753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accepts_dtmf_inputBoolean Also known as: accepts_dtmf_input?

Indicates whether DTMF input can be handled in the next request. Corresponds to the JSON property acceptsDtmfInput

Returns:

  • (Boolean)


10750
10751
10752
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 10750

def accepts_dtmf_input
  @accepts_dtmf_input
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10758
10759
10760
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 10758

def update!(**args)
  @accepts_dtmf_input = args[:accepts_dtmf_input] if args.key?(:accepts_dtmf_input)
end