Class: Google::Apis::DialogflowV2::GoogleCloudDialogflowV2SuggestConversationSummaryResponse
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV2::GoogleCloudDialogflowV2SuggestConversationSummaryResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v2/classes.rb,
lib/google/apis/dialogflow_v2/representations.rb,
lib/google/apis/dialogflow_v2/representations.rb
Overview
The response message for Conversations.SuggestConversationSummary.
Instance Attribute Summary collapse
-
#context_size ⇒ Fixnum
Number of messages prior to and including latest_message used to compile the suggestion.
-
#latest_message ⇒ String
The name of the latest conversation message used as context for compiling suggestion.
-
#summary ⇒ Google::Apis::DialogflowV2::GoogleCloudDialogflowV2SuggestConversationSummaryResponseSummary
Generated summary for a conversation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2SuggestConversationSummaryResponse
constructor
A new instance of GoogleCloudDialogflowV2SuggestConversationSummaryResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2SuggestConversationSummaryResponse
Returns a new instance of GoogleCloudDialogflowV2SuggestConversationSummaryResponse.
17561 17562 17563 |
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 17561 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context_size ⇒ Fixnum
Number of messages prior to and including latest_message used to compile the
suggestion. It may be smaller than the SuggestConversationSummaryRequest.
context_size field in the request if there weren't that many messages in the
conversation.
Corresponds to the JSON property contextSize
17548 17549 17550 |
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 17548 def context_size @context_size end |
#latest_message ⇒ String
The name of the latest conversation message used as context for compiling
suggestion. Format: projects//locations//conversations//messages/.
Corresponds to the JSON property latestMessage
17554 17555 17556 |
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 17554 def @latest_message end |
#summary ⇒ Google::Apis::DialogflowV2::GoogleCloudDialogflowV2SuggestConversationSummaryResponseSummary
Generated summary for a conversation.
Corresponds to the JSON property summary
17559 17560 17561 |
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 17559 def summary @summary end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17566 17567 17568 17569 17570 |
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 17566 def update!(**args) @context_size = args[:context_size] if args.key?(:context_size) @latest_message = args[:latest_message] if args.key?(:latest_message) @summary = args[:summary] if args.key?(:summary) end |