Class: Google::Apis::DialogflowV2::GoogleCloudDialogflowV2ToolCallResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v2/classes.rb,
lib/google/apis/dialogflow_v2/representations.rb,
lib/google/apis/dialogflow_v2/representations.rb

Overview

The result of calling a tool's action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudDialogflowV2ToolCallResult

Returns a new instance of GoogleCloudDialogflowV2ToolCallResult.



19080
19081
19082
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 19080

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Optional. The name of the tool's action associated with this call. Corresponds to the JSON property action

Returns:

  • (String)


19045
19046
19047
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 19045

def action
  @action
end

#answer_recordString

Optional. The answer record associated with this tool call result. Corresponds to the JSON property answerRecord

Returns:

  • (String)


19050
19051
19052
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 19050

def answer_record
  @answer_record
end

#contentString

Only populated if the response content is utf-8 encoded. Corresponds to the JSON property content

Returns:

  • (String)


19055
19056
19057
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 19055

def content
  @content
end

#create_timeString

Output only. Create time of the tool call result. Corresponds to the JSON property createTime

Returns:

  • (String)


19060
19061
19062
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 19060

def create_time
  @create_time
end

#errorGoogle::Apis::DialogflowV2::GoogleCloudDialogflowV2ToolCallResultError

An error produced by the tool call. Corresponds to the JSON property error



19065
19066
19067
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 19065

def error
  @error
end

#raw_contentString

Only populated if the response content is not utf-8 encoded. (by definition byte fields are base64 encoded). Corresponds to the JSON property rawContent NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


19072
19073
19074
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 19072

def raw_content
  @raw_content
end

#toolString

Optional. The tool associated with this call. Format: projects//locations// tools/. Corresponds to the JSON property tool

Returns:

  • (String)


19078
19079
19080
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 19078

def tool
  @tool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19085
19086
19087
19088
19089
19090
19091
19092
19093
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 19085

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @answer_record = args[:answer_record] if args.key?(:answer_record)
  @content = args[:content] if args.key?(:content)
  @create_time = args[:create_time] if args.key?(:create_time)
  @error = args[:error] if args.key?(:error)
  @raw_content = args[:raw_content] if args.key?(:raw_content)
  @tool = args[:tool] if args.key?(:tool)
end