Class: Google::Apis::DialogflowV2::GoogleCloudDialogflowV2beta1EventInput
- Inherits:
-
Object
- Object
- Google::Apis::DialogflowV2::GoogleCloudDialogflowV2beta1EventInput
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dialogflow_v2/classes.rb,
lib/google/apis/dialogflow_v2/representations.rb,
lib/google/apis/dialogflow_v2/representations.rb
Overview
Events allow for matching intents by event name instead of the natural
language input. For instance, input `can trigger a personalized welcome
response. The parameternamemay be used by the agent in the response:"
Hello #welcome_event.name! What can I do for you today?"`.
Instance Attribute Summary collapse
-
#language_code ⇒ String
Required.
-
#name ⇒ String
Required.
-
#parameters ⇒ Hash<String,Object>
The collection of parameters associated with the event.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1EventInput
constructor
A new instance of GoogleCloudDialogflowV2beta1EventInput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudDialogflowV2beta1EventInput
Returns a new instance of GoogleCloudDialogflowV2beta1EventInput.
20462 20463 20464 |
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 20462 def initialize(**args) update!(**args) end |
Instance Attribute Details
#language_code ⇒ String
Required. The language of this query. See Language Support for a list of the currently
supported language codes. Note that queries in the same session do not
necessarily need to specify the same language. This field is ignored when used
in the context of a WebhookResponse.followup_event_input field, because the
language was already defined in the originating detect intent request.
Corresponds to the JSON property languageCode
20442 20443 20444 |
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 20442 def language_code @language_code end |
#name ⇒ String
Required. The unique identifier of the event.
Corresponds to the JSON property name
20447 20448 20449 |
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 20447 def name @name end |
#parameters ⇒ Hash<String,Object>
The collection of parameters associated with the event. Depending on your
protocol or client library language, this is a map, associative array, symbol
table, dictionary, or JSON object composed of a collection of (MapKey,
MapValue) pairs: * MapKey type: string * MapKey value: parameter name *
MapValue type: If parameter's entity type is a composite entity then use map,
otherwise, depending on the parameter value type, it could be one of string,
number, boolean, null, list or map. * MapValue value: If parameter's entity
type is a composite entity then use map from composite entity property names
to property values, otherwise, use parameter value.
Corresponds to the JSON property parameters
20460 20461 20462 |
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 20460 def parameters @parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20467 20468 20469 20470 20471 |
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 20467 def update!(**args) @language_code = args[:language_code] if args.key?(:language_code) @name = args[:name] if args.key?(:name) @parameters = args[:parameters] if args.key?(:parameters) end |