Class: Google::Apis::DialogflowV2::GoogleTypeLatLng

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dialogflow_v2/classes.rb,
lib/google/apis/dialogflow_v2/representations.rb,
lib/google/apis/dialogflow_v2/representations.rb

Overview

An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleTypeLatLng

Returns a new instance of GoogleTypeLatLng.



24653
24654
24655
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 24653

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#latitudeFloat

The latitude in degrees. It must be in the range [-90.0, +90.0]. Corresponds to the JSON property latitude

Returns:

  • (Float)


24646
24647
24648
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 24646

def latitude
  @latitude
end

#longitudeFloat

The longitude in degrees. It must be in the range [-180.0, +180.0]. Corresponds to the JSON property longitude

Returns:

  • (Float)


24651
24652
24653
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 24651

def longitude
  @longitude
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24658
24659
24660
24661
# File 'lib/google/apis/dialogflow_v2/classes.rb', line 24658

def update!(**args)
  @latitude = args[:latitude] if args.key?(:latitude)
  @longitude = args[:longitude] if args.key?(:longitude)
end